{# Copyright (c) 2015 Chintalagiri Shashank Released under the MIT license #}
{% for part in stage.prototype.changelog.parts %} {% set outer_loop = loop %}

##### {{ part.title }}

{% for section in part.sections %}
- {{ section.title }}
  {% for entry in section.entries %}

  {{ entry.date.year }}

  {{ entry.date.month|monthname }} {{ entry.date.day }}

  {{ entry.initials }}
  {% for change in entry.changes %}
  - {{ change.body }}
  {% endfor %}

  {% endfor %}
{% endfor %}

{% endfor %}